summaryrefslogtreecommitdiffstats
path: root/khexedit/lib/kbytesedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'khexedit/lib/kbytesedit.h')
-rw-r--r--khexedit/lib/kbytesedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/khexedit/lib/kbytesedit.h b/khexedit/lib/kbytesedit.h
index 884f565..defb734 100644
--- a/khexedit/lib/kbytesedit.h
+++ b/khexedit/lib/kbytesedit.h
@@ -36,7 +36,7 @@ class KBytesEditPrivate;
*
* 1. used as viewer
* a) static data ranges -> no changes for data pointer and length
* possible changes are told to the widget by tqrepaintRange
* b) changing data ranges -> data pointer and length might change
* changes told by
* * resetData( char *, int size, bool tqrepaint );
@@ -138,7 +138,7 @@ class KHEXEDIT_EXPORT KBytesEdit : public KHexEdit
void setKeepsMemory( bool KM = true );
/** tqrepaint the indizes from i1 to i2 */
- void tqrepaintRange( int i1, int i2 );
+ void repaintRange( int i1, int i2 );
protected:
/** deletes the databuffer */
@@ -36,7 +36,7 @@ class KBytesEditPrivate;
* 1. used as viewer
* a) static data ranges -> no changes for data pointer and length
- * possible changes are told to the widget by tqrepaintRange
+ * possible changes are told to the widget by repaintRange
* b) changing data ranges -> data pointer and length might change
* changes told by